<?php
/*
Plugin Name: Easy Optimizer
Plugin URI: 
Description: A plugin to preload pages and lazy-load images to improve FCP, LCP (Largest Contentful Paint), and overall performance.
Version: 1.0.9
Author: 
Author URI: 
License: GPL2
*/


// If this file is called directly, abort.
if (!defined("WPINC")){
	die;
}

// Settings page
include('inc/options.php');

require_once dirname(__FILE__) . '/lib/simple_html_dom.php';

if ( function_exists( 'is_woocommerce' ) ) {
        $cart_url = parse_url( wc_get_cart_url(), PHP_URL_PATH );
        $checkout_url = parse_url( wc_get_checkout_url(), PHP_URL_PATH );
}

function easyopt_preload_enqueue_scripts() {
    // Enqueue preload.js
    $instant_preload = get_option( 'easyopt_instant_preload', 0 );
	if ( $instant_preload ) {
    wp_enqueue_script( 'instant-preload', plugin_dir_url( __FILE__ ) . 'assets/preload.min.js', array(), '', true );

    // Check if WooCommerce is active and get the cart and checkout URLs
    $site_origin = wp_parse_url( home_url(), PHP_URL_HOST );
    $cart_url = '';
    $checkout_url = '';

    if ( function_exists( 'is_woocommerce' ) ) {
        $cart_url = parse_url( wc_get_cart_url(), PHP_URL_PATH );
        $checkout_url = parse_url( wc_get_checkout_url(), PHP_URL_PATH );
    }

    // Enqueue the inline script with WooCommerce URLs added to the ignores array (if WooCommerce is active)
    wp_add_inline_script( 'instant-preload', "
        var instantPreloption = {
                timeout: 2000,
                timeoutFn: requestIdleCallback,
                origins: ['{$site_origin}'],
                ignores: [
                    uri => uri.includes('.php') || uri.includes('.pdf') || uri.includes('.zip') || uri.includes('#') || uri.includes('wp-admin') || uri.includes('/feed/') || uri.includes('feed=')" .
                    ( $cart_url ? " || uri.includes('{$cart_url}')" : "" ) .
                    ( $checkout_url ? " || uri.includes('{$checkout_url}')" : "" ) .
                    "
                ],
            };
    ", 'before' );
	}
}
add_action( 'wp_enqueue_scripts', 'easyopt_preload_enqueue_scripts' );


// Function to process the content and apply lazy loading using lazysizes
function eop_is_inside_wpadminbar( $element ) {
    while ( $element->parent() ) {
        $element = $element->parent();
        if ( $element->getAttribute( 'id' ) === 'wpadminbar' ) {
            return true;
        }
		if ($element->tag === 'noscript') {
            return true;
        }
    }
    return false;
}



function should_exclude_element($element, $exclude_values) {
    if (empty($exclude_values)) {
        return false;
    }

    $exclude_values_array = explode("\n", $exclude_values);
    foreach ($exclude_values_array as $exclude_value) {
        $exclude_value = trim($exclude_value);
        if (
            $exclude_value &&
            (
                strpos($element->getAttribute('class'), $exclude_value) !== false ||
                $element->parent()->hasClass($exclude_value) ||
                strpos($element, $exclude_value) !== false
				//
            )
        ) {
            return true;
        }
    }
    return false;
}


function easyopt_apply_lazy_loading( $content ) {


	// Get the options
    $lazy_load = get_option( 'easyopt_lazy_load', 0 );
    $exclude_values = get_option( 'easyopt_lazyload_exclude', '' );
    $exclude_first = intval( get_option( 'easyopt_lazyload_exclude_first', 2 ) );
	$html = eop_str_get_html($content, false, true, 'UTF-8', false, PHP_EOL, ' ');

    // Initialize a counter to keep track of the image index
    $image_index = 0;

    if ( $html && $lazy_load ) {
        // Find all img tags and apply lazy loading to appropriate images
        foreach ( $html->find( 'iframe' ) as $iframe ) {
			$has_lazyload_class = $iframe->hasClass('lazyload');
			$is_inside_wpadminbar = eop_is_inside_wpadminbar( $iframe );
            $has_base64_src = !filter_var($iframe->getAttribute('src'), FILTER_VALIDATE_URL);
			if ( ! $has_lazyload_class && ! $has_base64_src && ! $is_inside_wpadminbar) {
				$is_excluded = should_exclude_element($iframe, $exclude_values);
				if ( ! $is_excluded ) {
					$iframe->setAttribute( 'data-src', $iframe->getAttribute( 'src' ) );
					$iframe->removeAttribute( 'src' );
					$iframe->setAttribute( 'class', trim( $iframe->getAttribute( 'class' ) . ' lazyload' ) );
					
				}
				
			}
			
			
		}
		foreach ($html->find('[style*=background-image]') as $element) {
    // Check if the element has the lazyload class or data-bg attribute
    $has_lazyload_class = $element->hasClass('lazyload');
    $has_data_bg_attribute = $element->hasAttribute('data-bg');

    if (!$has_lazyload_class && !$has_data_bg_attribute) {
        $is_excluded = should_exclude_element($element, $exclude_values);
        if (!$is_excluded) {
            // Extract the URL from the background-image style
            if (preg_match('/background-image\s*:\s*url\(\s*([^\)]+)\s*\)/i', $element->getAttribute('style'), $matches)) {
        $background_image_url = html_entity_decode($matches[1]);

        // Remove single and double quotes from the URL
        $background_image_url = str_replace(['"', "'", '&#039;'], '', $background_image_url);

        // Add data-bg attribute with the extracted URL
        $element->setAttribute('data-bg', $background_image_url);
        $element->setAttribute('class', trim($element->getAttribute('class') . ' lazyload'));

        // Remove the background-image style
        $element->setAttribute('style', preg_replace('/background-image\s*:\s*url\(\s*([^\)]+)\s*\)\s*;?/i', '', $element->getAttribute('style')));
    }
        }
    }
}

		
		foreach ( $html->find( 'video' ) as $video ) {
			$has_lazyload_class = $video->hasClass('lazyload');
            $has_base64_src = ( strpos( $video->getAttribute('src'), '#' ) !== false );
			if ( ! $has_lazyload_class && ! $has_base64_src ) {
				$is_excluded = should_exclude_element($video, $exclude_values);
				if ( ! $is_excluded ) {
					$video->setAttribute( 'data-poster', $video->getAttribute( 'poster' ) );
					$video->removeAttribute('poster');
					$video->setAttribute( 'preload', 'none');
					$video->setAttribute( 'data-autoplay', $video->getAttribute( 'autoplay' ) );
					$video->removeAttribute('autoplay');
					$video->setAttribute( 'class', trim( $video->getAttribute( 'class' ) . ' lazyload' ) );
					
				}
			}
			
			
		}
		
        foreach ( $html->find( 'img' ) as $img ) {
            // Check if the img tag has the class "lazyload" or contains base64 src or is inside the wpadminbar
            $has_lazyload_class = $img->hasClass('lazyload') || $img->hasClass('rplg-blazy') || $img->hasClass('rs-lazyload');
            $has_base64_src = ( strpos( $img->getAttribute('src'), 'base64' ) !== false ) ||( strpos( $img->getAttribute('src'), 'data:image' ) !== false );
            $is_inside_wpadminbar = eop_is_inside_wpadminbar( $img );

            if ( ! $has_lazyload_class && ! $has_base64_src && ! $is_inside_wpadminbar ) {
                // Check if the img tag should be excluded based on user's settings
                $is_excluded = should_exclude_element($img, $exclude_values);

                // Check if the img tag is among the first excluded images
                $is_first_excluded_image = ( $image_index < $exclude_first );
				$imgwidth  = $img->getAttribute( 'width' );
		        $imgheight = $img->getAttribute( 'height' );
			    if (empty($imgwidth) && empty($imgheight)) {
						$src = $img->getAttribute('src');
						$headers = get_headers($src);
                        if (strpos($headers[0], '200') !== false) {
                        list($width, $height) = getimagesize($src);
                        if ($width && $height) {
                         $img->setAttribute('width', $width);
                         $img->setAttribute('height', $height);
                        }
                     }
			    }

                if ( ! $is_excluded && ! $is_first_excluded_image ) {
                    // Check if the img tag has srcset
                    $has_srcset = $img->hasAttribute( 'srcset' );
					
					if (!empty($imgwidth) && !empty($imgheight)) {
					$placeholder = "data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 $imgwidth $imgheight'%3E%3C/svg%3E";
					} elseif (!empty($width) && !empty($height))  {
						$placeholder = "data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 $width $height'%3E%3C/svg%3E";	
					} else {
						$placeholder = "data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7";
					}

                    // Replace srcset with data-srcset if it exists
                    if ( $has_srcset ) {
                        $img->setAttribute( 'data-srcset', $img->getAttribute( 'srcset' ) );
						$img->removeAttribute( 'srcset' );
						$img->setAttribute( 'data-src', $img->getAttribute( 'src' ) );
                        $img->setAttribute( 'src', $placeholder );
                    } else {
                        // Add data-src attribute if no srcset exists
                        $img->setAttribute( 'data-src', $img->getAttribute( 'src' ) );
                        $img->setAttribute( 'src', $placeholder);
                    }
					$picture = $img->parent();
                    $sources = $picture->find( 'source' );

                    foreach ( $sources as $source ) {
						if ( $source->hasAttribute( 'srcset' ) ) {
							$source->setAttribute( 'data-srcset', $source->getAttribute( 'srcset' ) );
							$source->removeAttribute( 'srcset' );
						}
					}

                    // Add the lazysizes class without removing existing classes
                    $img->setAttribute( 'class', trim( $img->getAttribute( 'class' ) . ' lazyload' ) );
                }

                // Increment the image index
                $image_index++;
            }
        }

        // Get the modified HTML back as a string
        
    }

    $content = $html->save();
    return $content;
}
function easyopt_adding_scripts() {
	$lazy_load = get_option( 'easyopt_lazy_load', 0 );
	if ( $lazy_load ) {
		wp_register_script('easy-lazyload', plugin_dir_url( __FILE__ ) . 'assets/lazyload.min.js','','1.0.2', true);
		wp_enqueue_script('easy-lazyload');
	}
}
add_action( 'wp_enqueue_scripts', 'easyopt_adding_scripts' );  

function easyopt_modify_content_with_cdn($html) {
    $img_opt = get_option('easyopt_img_opt', 0);
    $current_domain = parse_url(home_url(), PHP_URL_HOST);
    $is_https = is_ssl() ? 'https://' : 'http://';
    $domain_url = get_site_url();

    // CDN URL
    $cdn_url = 'https://cdn.shortpixel.ai/spai/q_glossy+to_auto+ret_img/';
	
    if ($html && $img_opt) {
        $exclude_img_values = get_option('easyopt_image_exclude', ''); // Get the excluded values

		$html = preg_replace('/(["\'])\/\/' . preg_quote($current_domain, '/') . '/', '$1' . $is_https . $current_domain, $html);
        $old_url = get_site_url();
        $new_url = "https://cdn.shortpixel.ai/spai/q_glossy+to_auto+ret_img/$old_url";
        $pattern = '/<img\s+[^>]*src=[\'"][^\'"]+\.(?:png|jpg|jpeg|gif)[^\'"]*[\'"][^>]*>|(background(?:-image)?:\s*(.*?)\s*url\()([\'"]?)([^\'")]+)([\'"]?\))|data-bg\s*=\s*([\'"])([^\'"]+)([\'"])/i';
        $html = preg_replace_callback($pattern, function ($match) use ($old_url, $new_url, $exclude_img_values) {
            $img_tag = $match[0];

            // Check if the image should be excluded based on user-defined criteria
            $exclude = false;
            foreach (explode("\n", $exclude_img_values) as $exclude_img_value) {
                $exclude_img_value = trim($exclude_img_value);
                if ($exclude_img_value && (stripos($img_tag, $exclude_img_value) !== false)) {
                    $exclude = true;
                    break;
                }
            }

            if (!$exclude) {
                $new_img_tag = str_replace($old_url, $new_url, $img_tag);
                return $new_img_tag;
            } else {
                return $img_tag; // Return the original image tag if excluded
            }
        }, $html);
    }
    
    return $html;
}

function easy_replace_elcss_property( $control, $value ) {
	$cdn_domain = 'https://cdn.shortpixel.ai/spai/q_glossy+to_auto+ret_img/';
	foreach ( $control['selectors'] as $selector => $css_property ) {
		if ( 0 === strpos( $css_property, 'background-image' ) && strpos( $css_property, 'background-color' ) === false ) {
			if ( ! empty( $value['url'] ) ) {
				$image_url = 'url("' . $cdn_domain . $value['url'] . '")';
				$control['selectors'][$selector] = str_replace( 'url("{{URL}}")', $image_url, $css_property );
			}
		}
	}
	return $control;
}

// Check if Elementor is active
// Check if Elementor is active
function easyopt_custom_css_filter() {
    if (class_exists('Elementor\Plugin')) {
        $img_opt = get_option('easyopt_img_opt', 0);
        $easy_elementor_css_method = get_option('elementor_css_print_method');

        // Check if Elementor is using internal embedding for CSS
        if ($easy_elementor_css_method === 'external' && $img_opt) {
            add_filter('elementor/files/css/selectors', function ($control, $value) {
                return easy_replace_elcss_property($control, $value);
            }, 10, 2);
        }
    }
}

// Hook the custom_elementor_css_filter function to run after plugins are loaded
add_action('setup_theme', 'easyopt_custom_css_filter');


function run_easyopt_template_redirect() {
	//ob_start();
	ob_start( 'easyopt_modify_content_with_cdn',0, PHP_OUTPUT_HANDLER_REMOVABLE );
	
	ob_start( 'easyopt_apply_lazy_loading',0, PHP_OUTPUT_HANDLER_REMOVABLE );
}
add_action( 'template_redirect', 'run_easyopt_template_redirect', 1001 );

// Enqueue admin script on option page
function easy_opt_admin_enqueue_scripts( $hook_suffix ) {
  // Check if we are on the option page
  if ( 'settings_page_easy-optimizer' !== $hook_suffix ) {
    return;
  }

  wp_enqueue_script( 'easy-add-remove-fields', plugin_dir_url( __FILE__ ) . 'assets/script.js', array('jquery'), '1.0.1', true );
}
add_action( 'admin_enqueue_scripts', 'easy_opt_admin_enqueue_scripts' );


// enqueue admin styles on option page
function easy_opt_admin_enqueue_plugin_styles( $hook ) {
  if ( 'settings_page_easy-optimizer' === $hook ) {
    wp_enqueue_style( 'lazyplugin-styles', plugin_dir_url( __FILE__ ) . 'assets/style.css', '', '1.0.1', false );
  }
}
add_action( 'admin_enqueue_scripts', 'easy_opt_admin_enqueue_plugin_styles' );


// plugin action settings
function easy_opt_add_settings_link( $links ) {
  $settings_link = '<a href="' . admin_url( 'options-general.php?page=easy-optimizer' ) . '">' . __( 'Settings' ) . '</a>';
  array_unshift( $links, $settings_link );
  return $links;
}
add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'easy_opt_add_settings_link' );