<?php

// Register options page under Settings menu
function easyopt_register_options_page() {
    add_options_page( 'Easy Optimizer Settings', 'Easy Optimizer', 'manage_options', 'easy-optimizer', 'easyopt_options_page_callback' );
}
add_action( 'admin_menu', 'easyopt_register_options_page' );

// Callback function to render the options page
function easyopt_options_page_callback() {
    ?><form method="post" action="options.php">
	<div class="title"><h1><?php esc_html_e( 'Easy Optimizer Settings', 'easyopt' ); ?></h1></div>
    <div class="eop_wrap">
        
        
            <?php
            settings_fields( 'easyopt_settings_group' );
	        //do_settings_sections( 'easyoptimg-settings' );

            // Enable Instant Preload
            $instant_preload = get_option( 'easyopt_instant_preload', 0 );
            ?>
		    <div class="instantpre">
			<h2>Instant Pageload</h2>
			
            <label for="easyopt_instant_preload">
                <input type="checkbox" id="easyopt_instant_preload" name="easyopt_instant_preload" value="1" <?php checked( $instant_preload, 1 ); ?>>
                <?php esc_html_e( 'Preloading Pages makes navigations to subsequent pages load faster.', 'easyopt' ); ?>
            </label>
			</div>

            <!-- Lazy Load Images & Iframes -->
		    <div class="lazyload">
            <h2><?php esc_html_e( 'Lazy Load Images & Iframes', 'easyopt' ); ?></h2>
            <?php
            $lazy_load = get_option( 'easyopt_lazy_load', 0 );
            ?>
            
                <label for="easyopt_lazy_load">
                    <input type="checkbox" id="easyopt_lazy_load" name="easyopt_lazy_load" value="1" <?php checked( $lazy_load, 1 ); ?>>
                    <?php esc_html_e( 'Lazy Load Images, Iframe, Videos', 'easyopt' ); ?>
                </label>
            
            <?php
            $exclude_values = get_option( 'easyopt_lazyload_exclude', '' );
            ?><div class="lazyfield">

            <textarea placeholder="Enter image or iframe class name, parent class name, or image url (one per line) to exclude them from lazy loading." id="easyopt_lazyload_exclude" name="easyopt_lazyload_exclude" rows="4" cols="50"><?php echo esc_textarea( $exclude_values ); ?></textarea>
            <p class="description"><?php esc_html_e( 'Enter class names, parent class names, or image src strings (one per line) to exclude them from lazy loading.', 'easyopt' ); ?></p>
            <?php
            $exclude_first = get_option( 'easyopt_lazyload_exclude_first', 2 );
            ?>
            <input type="number" id="easyopt_lazyload_exclude_first" name="easyopt_lazyload_exclude_first" value="<?php echo esc_attr( $exclude_first ); ?>" min="0" step="1">
            <p class="description"><?php esc_html_e( 'Enter the number of images (starting from the first) to exclude from lazy loading.', 'easyopt' ); ?></p></div></div>

            <!-- Image Optimization -->
            <h2><?php esc_html_e( 'Image Optimization', 'easyopt' ); ?></h2>
		    <p class="description">Shortpixel - Convert Images to webp or Avif (auto supported by browser). You need to signup <b><a target="_blank" href="https://easywpstuff.com/shortpixel">Shortpixel Here</a></b> then just associate your domain. That's it. Enjoy 500MB of free usage per month.</p><p>Your images will be optimized and automatically converted to WebP and AVIF formats on fly After a few minutes. It's super simple and no need to worry about losing quality, preserving the original image, creating backups, or converting locally, which can consume storage. <br> To confirm image format in your browser, follow these steps: Right-click and select "Inspect" or "Inspect Element," then navigate to the "Network" tab.</p>
            <?php
            $img_opt = get_option( 'easyopt_img_opt', 0 );
            ?>
            <div class="imgopt">
                <label for="easyopt_img_opt">
                    <input type="checkbox" id="easyopt_img_opt" name="easyopt_img_opt" value="1" <?php checked( $img_opt, 1 ); ?>>
                    <?php esc_html_e( 'Enable Image Optimization', 'easyopt' ); ?>
                </label>
            
            <?php
            $exclude_img_values = get_option( 'easyopt_image_exclude', '' );
            ?><div class="imgoptfield">
            <textarea id="easyopt_image_exclude" name="easyopt_image_exclude" rows="4" cols="50"><?php echo esc_textarea( $exclude_img_values ); ?></textarea>
            <p class="description"><?php esc_html_e( 'Enter class names, or image URLs (one per line) to exclude them from Optimization.', 'easyopt' );?></p><?php if (class_exists('Elementor\Plugin')) {?><p>If you are using Elementor background images, don't forget to <a href="<?php $url = site_url(); echo esc_url($url . '/wp-admin/admin.php?page=elementor-tools'); ?>">Regenerate Elementor CSS</a></p><?php } ?></div></div>

            <?php submit_button(); ?>
        
    </div></form>
    <?php
}

// Register settings and fields
function easyopt_register_settings() {
    register_setting( 'easyopt_settings_group', 'easyopt_instant_preload' );
    register_setting( 'easyopt_settings_group', 'easyopt_lazyload_exclude' );
    register_setting( 'easyopt_settings_group', 'easyopt_lazyload_exclude_first' );
	register_setting( 'easyopt_settings_group', 'easyopt_lazy_load' );
	register_setting( 'easyopt_settings_group', 'easyopt_img_opt' );
	register_setting( 'easyopt_settings_group', 'easyopt_image_exclude' );

    
}
add_action( 'admin_init', 'easyopt_register_settings' );

// Section callback


// Save the checkbox value with sanitization
function easyopt_save_settings() {
    $instant_preload = isset( $_POST['easyopt_instant_preload'] ) ? 1 : 0;
	$lazy_load = isset( $_POST['easyopt_lazy_load'] ) ? 1 : 0;
    $exclude_values = isset( $_POST['easyopt_lazyload_exclude'] ) ? wp_kses_post( $_POST['easyopt_lazyload_exclude'] ) : '';
    $exclude_first = isset( $_POST['easyopt_lazyload_exclude_first'] ) ? absint( $_POST['easyopt_lazyload_exclude_first'] ) : 2;
	$img_opt = isset( $_POST['easyopt_img_opt'] ) ? 1 : 0;
	$exclude_img_values = isset( $_POST['easyopt_image_exclude'] ) ? wp_kses_post( $_POST['easyopt_image_exclude'] ) : '';

    update_option( 'easyopt_instant_preload', $instant_preload );
	update_option( 'easyopt_lazy_load', $lazy_load );
    update_option( 'easyopt_lazyload_exclude', $exclude_values );
    update_option( 'easyopt_lazyload_exclude_first', $exclude_first );
	update_option( 'easyopt_img_opt', $img_opt );
	update_option( 'easyopt_image_exclude', $exclude_img_values );
}